==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu.js <==
/**
 * Horizontal menu object
 *
 * <p item>	is text content of menu
 *			if value is equal to '-' than <hr> tag is used instead of link
 *
 * Input array example:
 * x[<p item>]	[arg] = obj | string
 *				[disabled]
 *				[css] = 'className'
 *				[nodes][<ch item>]	[arg]
 *									[css]
 *									[nodes]
 **/
_me = obj_hmenu.prototype;
function obj_hmenu(){};

_me.__constructor = function(){

	this.__idtable = {};

	var me = this;
	/* onclick handler */
	this._main.onclick = function(e){
		var e = e || window.event;

		// stop event propagation
		e.cancelBubble = true;
		if (e.stopPropagation) e.stopPropagation();
		
		// ELEMENT which caused event
		var elm = e.target || e.srcElement;
		
		if (elm.tagName!='A') return;
		
		// parse id
		var id = elm.id.substr(me._pathName.length+1);
		
		if (me.__idtable[id] && me.__idtable[id].disabled) return false;

        if (me.__close) me.__close();  //it may by placed in obj_hmenu_plus
        
		me._onclick(e,elm,id,me.__idtable[id].arg || '');
		me.__exeEvent('onsort',e,{"arg":me.__idtable[id].arg,"id":id,"elm":elm,"owner":me});

		return false;
	};

	this._main.oncontextmenu = function (e){
		return false;
	};
};

_me._fill = function (aData){
	/* retrieve data from dataset */

	this._clear();
	if (!aData) aData = dataSet.get(this._listener,this._listenerPath);
	if (!aData)	return;

	this.__row(aData,'');
};

_me._clear = function (){
	/* clear the hmenu window */
	this._main.innerHTML = '';
};

_me.__row = function(aData,child){
	var elm1,elm2,elm3,elm4,elm5,elm6,me = this;

//inspect2(aData);
	/* clear container object */
	//this._main.innerHTML = '';
	/* create main UL element */
	elm1 = mkElement("ul");

	var path;
	if (!child) {
		/* prepare path */
		this.__idtable = {};
		path = '';
		/* set class for main UL element */
		elm1.className = this._main.className;
	}
	else
		path = child;

	var n = 0;

	for(var i in aData){
		elm2 = mkElement("li");

		/* horizontal line */
		if (aData[i]['title'] == '-'){
			elm3 = mkElement('div');
			elm3.innerHTML = '&nbsp;';
			addcss(elm2,'hr');
			delete aData[i]['nodes'];
		}
		else
		/* blank, create Anchor*/
		if (aData[i]['anchor']){
			elm3 = mkElement('div');
			elm3.id = this._pathName + '/' + path + '/' + aData[i]['anchor'];
			delete aData[i]['nodes'];

			this._anchors[aData[i]['anchor']] = elm3.id;
			if (aData[i]['css']) addcss(elm3,aData[i]['css']);
		}
		/* link */
		else{
			elm3 = mkElement("a",{"href":'',"className":'menuitem'});
			elm3.unselectable = "on";

			if (aData[i]['arg'])
				this.__idtable[path + n] = {arg:aData[i]['arg']};

			if (aData[i]['css']) addcss(elm3,aData[i]['css']);
			if (aData[i]['nodes']) {
				addcss(elm3,'nodes');
				if (this.__idtable[path + n])
					this.__idtable[path + n].nodes = true;
				else
					this.__idtable[path + n] = {"nodes":true};
			}
			if (aData[i]['disabled']){
				addcss(elm3,'disabled');
				if (this.__idtable[path + n])
					this.__idtable[path + n].disabled = true;
				else
					this.__idtable[path + n] = {"disabled":true};
			}
			if (aData[i]['caption']){
				addcss(elm3,'caption');
				if (this.__idtable[path + n])
					this.__idtable[path + n].disabled = true;
				else
					this.__idtable[path + n] = {"disabled":true};
			}
			
			if (typeof aData[i]['title'] == 'string')
				elm3.innerHTML = aData[i]['title'].length?getLang(aData[i]['title']):'&nbsp;';
			else
			if (typeof aData[i]['text'] == 'string')
				elm3.innerHTML = aData[i]['text'].length?aData[i]['text']:'&nbsp;';
			else
				elm3.innerHTML = i;

			elm3.id = this._pathName + '/' + path + n;
		}

		elm2.appendChild(elm3);

		if (aData[i]['nodes']){
			elm2.onmouseover = function(e){
				var elm = this.getElementsByTagName("UL")[0];
				elm.className = "open";
				elm = null;
				try{
					var elm = this.getElementsByTagName('A')[0];
					addcss(elm,'active');
					elm = null;
				}
				catch(ee){}
			};
			
			elm2.onmouseout = function(e){
				var elm = this.getElementsByTagName("UL")[0];
				elm.className = "";
				elm = null;
				try{
					var elm = this.getElementsByTagName('A')[0];
					removecss(elm,'active');
					elm = null;
				}
				catch(ee){}
			};
			
			/* parse and append child nodes */
			elm2.appendChild(this.__row(aData[i]['nodes'],path + n + '/'));
		}
		n++;
		elm1.appendChild(elm2);
	}

	/* set "end" className for last node with childs */
	if (elm2){
		addcss(elm2,'end');
		/* destruct html elements */
		elm2 = null;
		elm3 = null;
	}

	/* append root UL element into _main */
	if (!child) {
		this._main.appendChild(elm1);
		return;
	}

	/* return UL element */
	return elm1;
};


_me.__update = function(){
	this._fill();
};

/**
 * @brief: optional onclick method
 * @param: e    - Event Handler (onclick event object)
 *         elm  - srcElement (link)
 *         id   - objects internal id (without pathName)
 *         arg  - item's arg section
 *
 * _me._onclick = function(e,elm,id,arg){};
 */

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu.js <==
/**
 * Horizontal menu object
 *
 * <p item>	is text content of menu
 *			if value is equal to '-' than <hr> tag is used instead of link
 *
 * Input array example:
 * x[<p item>]	[arg] = obj | string
 *				[disabled]
 *				[css] = 'className'
 *				[nodes][<ch item>]	[arg]
 *									[css]
 *									[nodes]
 **/
_me = obj_hmenu.prototype;
function obj_hmenu(){};

_me.__constructor = function(){

	this.__idtable = {};

	var me = this;
	/* onclick handler */
	this._main.onclick = function(e){
		var e = e || window.event;

		// stop event propagation
		e.cancelBubble = true;
		if (e.stopPropagation) e.stopPropagation();
		
		// ELEMENT which caused event
		var elm = e.target || e.srcElement;
		
		if (elm.tagName!='A') return;
		
		// parse id
		var id = elm.id.substr(me._pathName.length+1);
		
		if (me.__idtable[id] && me.__idtable[id].disabled) return false;

        if (me.__close) me.__close();  //it may by placed in obj_hmenu_plus
        
		me._onclick(e,elm,id,me.__idtable[id].arg || '');
		me.__exeEvent('onsort',e,{"arg":me.__idtable[id].arg,"id":id,"elm":elm,"owner":me});

		return false;
	};

	this._main.oncontextmenu = function (e){
		return false;
	};
};

_me._fill = function (aData){
	/* retrieve data from dataset */

	this._clear();
	if (!aData) aData = dataSet.get(this._listener,this._listenerPath);
	if (!aData)	return;

	this.__row(aData,'');
};

_me._clear = function (){
	/* clear the hmenu window */
	this._main.innerHTML = '';
};

_me.__row = function(aData,child){
	var elm1,elm2,elm3,elm4,elm5,elm6,me = this;

	/* create main UL element */
	elm1 = mkElement("ul");

	var path;
	if (!child) {
		/* prepare path */
		this.__idtable = {};
		path = '';
		/* set class for main UL element */
		elm1.className = this._main.className;
	}
	else
		path = child;

	var n = 0;

	for(var i in aData){
		elm2 = mkElement("li");

		/* horizontal line */
		if (aData[i]['title'] == '-'){
			elm3 = mkElement('div');
			elm3.innerHTML = '&nbsp;';
			addcss(elm2,'hr');
			delete aData[i]['nodes'];
		}
		else
		/* blank, create Anchor*/
		if (aData[i]['anchor']){
			elm3 = mkElement('div');
			elm3.id = this._pathName + '/' + path + aData[i]['anchor'];
			delete aData[i]['nodes'];

			this._anchors[aData[i]['anchor']] = elm3.id;
			if (aData[i]['css']) addcss(elm3,aData[i]['css']);
		}
		/* link */
		else{
			elm3 = mkElement("a",{"href":'',"className":'menuitem'});
			elm3.unselectable = "on";

			if (aData[i]['arg'])
				this.__idtable[path + n] = {arg:aData[i]['arg']};

			if (aData[i]['css']) addcss(elm3,aData[i]['css']);
			if (aData[i]['nodes']) {
				addcss(elm3,'nodes');
				if (this.__idtable[path + n])
					this.__idtable[path + n].nodes = true;
				else
					this.__idtable[path + n] = {"nodes":true};
			}
			if (aData[i]['disabled']){
				addcss(elm3,'disabled');
				if (this.__idtable[path + n])
					this.__idtable[path + n].disabled = true;
				else
					this.__idtable[path + n] = {"disabled":true};
			}
			if (aData[i]['caption']){
				addcss(elm3,'caption');
				if (this.__idtable[path + n])
					this.__idtable[path + n].disabled = true;
				else
					this.__idtable[path + n] = {"disabled":true};
			}
			
			if (typeof aData[i]['title'] == 'string')
				elm3.innerHTML = aData[i]['title'].length?getLang(aData[i]['title']):'&nbsp;';
			else
			if (typeof aData[i]['text'] == 'string')
				elm3.innerHTML = aData[i]['text'].length?aData[i]['text']:'&nbsp;';
			else
				elm3.innerHTML = i;

			elm3.id = this._pathName + '/' + path + n;
		}

		if (aData[i]['nodes']){
			elm2.onmouseover = function(e){
				var elm = this.getElementsByTagName("UL")[0];
				elm.className = "open";
				elm = null;
				try{
					var elm = this.getElementsByTagName('A');
						elm = elm[elm.length-1];
					addcss(elm,'active');
					elm = null;
				}
				catch(ee){}
			};
			
			elm2.onmouseout = function(e){
				var elm = this.getElementsByTagName("UL")[0];
				elm.className = "";
				elm = null;
				try{
					var elm = this.getElementsByTagName('A');
						elm = elm[elm.length-1];
					removecss(elm,'active');
					elm = null;
				}
				catch(ee){}
			};
			
			/* parse and append child nodes */
			elm2.appendChild(this.__row(aData[i]['nodes'],path + n + '/'));
		}

		elm2.appendChild(elm3);
		
		n++;
		elm1.appendChild(elm2);
	}

	/* set "end" className for last node with childs */
	if (elm2){
		addcss(elm2,'end');
		/* destruct html elements */
		elm2 = null;
		elm3 = null;
	}

	/* append root UL element into _main */
	if (!child) {
		this._main.appendChild(elm1);
		return;
	}

	/* return UL element */
	return elm1;
};


_me.__update = function(){
	this._fill();
};

/**
 * @brief: optional onclick method
 * @param: e    - Event Handler (onclick event object)
 *         elm  - srcElement (link)
 *         id   - objects internal id (without pathName)
 *         arg  - item's arg section
 *
 * _me._onclick = function(e,elm,id,arg){};
 */
